@@ -1,4 +1,54 @@
 
+#'
+#' Checks if filepath ends in suffix. If suffix does not start with a '.' it is prepended automatically.
+#' 
+#' @param filepath A relative or absolute path to a file, whose suffix is checked
+#' @param suffix This is the suffix we expect (the '.' is prepended internally if missing)
+#' @return TRUE if yes, FALSE otherwise
+#' 
+#' @export
+#' 
+#' @examples 
+#'   hasFileSuffix("bla.txt", "txt")    # TRUE
+#'   hasFileSuffix("bla.txt", ".txt")   # TRUE
+#'   hasFileSuffix("bla.txt", "doc")    # FALSE
+#'   hasFileSuffix("bla.txt", ".doc")   # FALSE
+#'   hasFileSuffix("fo", ".doc")        # FALSE
+#'   hasFileSuffix("", ".doc")          # FALSE
+#'   hasFileSuffix("foo", "")           # FALSE
+#' 
+hasFileSuffix = function(filepath, suffix)
+{
+  if (substr(suffix,1,1) != '.') suffix = paste0('.', suffix)
+  
+  filepath = tolower(filepath)
+  suffix = tolower(suffix)
+  
+  return(suffix == substring(filepath, first = nchar(filepath) - nchar(suffix) + 1))
+}
+
+
+#'
+#' Removes the last suffix (including the last dot) from a filename.
+#' If no dot exists, the full string is returned.
+#' 
+#' @param filepath A filename (with optional path -- which is retained!)
+#' @return The input with removed suffix
+#' 
+#' @examples 
+#'  removeSuffix("test.tar.gz")  # --> 'test.tar'
+#'  removeSuffix("test.mzML")  # --> 'test'
+#'  removeSuffix("/path/to/test.mzML")  # --> '/path/to/test'
+#'  removeSuffix("test_no_dot")  # --> 'test_no_dot'
+#' 
+#' @export
+#'
+removeSuffix = function(filepath)
+{
+  gsub("(.*)\\..*$", "\\1", filepath)
+}
+
+
 #'
 #' Get the longest common prefix from a set of strings.
 #' 
@@ -938,7 +988,7 @@ getAbundanceClass = function(x) {
 #'        
 #' @return List of output file names (just names, no file is created) 
 #'         with list entries: 
-#'         **yaml_file**, **heatmap_values_file**, **R_plots_file**, **filename_sorting**, **stats_file**, **log_file**, **report_file_prefix**, **report_file_PDF**, **report_file_HTML**
+#'         **yaml_file**, **heatmap_values_file**, **R_plots_file**, **filename_sorting**, **mzQC_file**, **log_file**, **report_file_prefix**, **report_file_PDF**, **report_file_HTML**
 #' 
 #' @export
 #' 
@@ -978,9 +1028,8 @@ getReportFilenames = function(folder, report_name_has_folder = TRUE, mzTab_filen
             heatmap_values_file = paste0(report_file_prefix, "_heatmap.txt"),
             R_plots_file = paste0(report_file_prefix, "_plots.Rdata"),
             filename_sorting = paste0(report_file_prefix, "_filename_sort.txt"),
-            stats_file = paste0(report_file_prefix, "_stats.txt"),
+            mzQC_file = paste0(report_file_prefix, ".mzQC"),
             log_file = paste0(report_file_prefix, ".log"),
-            qc_file = paste0(report_file_prefix, ".mzQC"),
             report_file_prefix = report_file_prefix,
             report_file_PDF = paste0(report_file_prefix, ".pdf"),
             report_file_HTML = paste0(report_file_prefix, ".html")
